@@ -2,6 +2,7 @@ import os
 import re
 
 from AnnotatedSentence.ViewLayerType import ViewLayerType
+from Corpus.FileDescription import FileDescription
 from ParseTree.TreeBank import TreeBank
 
 from AnnotatedTree.ParseTreeDrawable import ParseTreeDrawable
@@ -16,10 +17,10 @@ class TreeBankDrawable(TreeBank):
                 for file in files:
                     fileName = os.path.join(root, file)
                     if (pattern is None or pattern in fileName) and re.match("\\d+\\.", file):
-                        print(fileName)
                         parseTree = ParseTreeDrawable(fileName)
                         if parseTree.getRoot() is not None:
                             parseTree.setName(fileName)
+                            parseTree.setFileDescription(FileDescription(root, file))
                             self.parseTrees.append(parseTree)
 
     def getParseTrees(self) -> list:
